restrict

package
v1.9.10 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	Restrict_GetRestrictArea_FullMethodName         = "/public.Restrict/GetRestrictArea"
	Restrict_InsertRestrictData_FullMethodName      = "/public.Restrict/InsertRestrictData"
	Restrict_UpdateRestrictData_FullMethodName      = "/public.Restrict/UpdateRestrictData"
	Restrict_RestrictDataList_FullMethodName        = "/public.Restrict/RestrictDataList"
	Restrict_DelRestrictData_FullMethodName         = "/public.Restrict/DelRestrictData"
	Restrict_InsertBatchRestrictData_FullMethodName = "/public.Restrict/InsertBatchRestrictData"
)

Variables

var File_restrict_proto protoreflect.FileDescriptor
var Restrict_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "public.Restrict",
	HandlerType: (*RestrictServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetRestrictArea",
			Handler:    _Restrict_GetRestrictArea_Handler,
		},
		{
			MethodName: "InsertRestrictData",
			Handler:    _Restrict_InsertRestrictData_Handler,
		},
		{
			MethodName: "UpdateRestrictData",
			Handler:    _Restrict_UpdateRestrictData_Handler,
		},
		{
			MethodName: "RestrictDataList",
			Handler:    _Restrict_RestrictDataList_Handler,
		},
		{
			MethodName: "DelRestrictData",
			Handler:    _Restrict_DelRestrictData_Handler,
		},
		{
			MethodName: "InsertBatchRestrictData",
			Handler:    _Restrict_InsertBatchRestrictData_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "restrict.proto",
}

Restrict_ServiceDesc is the grpc.ServiceDesc for Restrict service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterRestrictServer

func RegisterRestrictServer(s grpc.ServiceRegistrar, srv RestrictServer)

Types

type DelOneRestrictDataPara

type DelOneRestrictDataPara struct {
	Id int32 `protobuf:"varint,1,opt,name=Id,proto3" json:"Id,omitempty"`
	// contains filtered or unexported fields
}

func (*DelOneRestrictDataPara) Descriptor deprecated

func (*DelOneRestrictDataPara) Descriptor() ([]byte, []int)

Deprecated: Use DelOneRestrictDataPara.ProtoReflect.Descriptor instead.

func (*DelOneRestrictDataPara) GetId

func (x *DelOneRestrictDataPara) GetId() int32

func (*DelOneRestrictDataPara) ProtoMessage

func (*DelOneRestrictDataPara) ProtoMessage()

func (*DelOneRestrictDataPara) ProtoReflect

func (x *DelOneRestrictDataPara) ProtoReflect() protoreflect.Message

func (*DelOneRestrictDataPara) Reset

func (x *DelOneRestrictDataPara) Reset()

func (*DelOneRestrictDataPara) String

func (x *DelOneRestrictDataPara) String() string

type InsertBatchRestrictDataPara

type InsertBatchRestrictDataPara struct {
	PathUrl string `protobuf:"bytes,1,opt,name=pathUrl,proto3" json:"pathUrl,omitempty"`
	Company string `protobuf:"bytes,2,opt,name=Company,proto3" json:"Company,omitempty"`
	Name    string `protobuf:"bytes,3,opt,name=Name,proto3" json:"Name,omitempty"`
	// contains filtered or unexported fields
}

func (*InsertBatchRestrictDataPara) Descriptor deprecated

func (*InsertBatchRestrictDataPara) Descriptor() ([]byte, []int)

Deprecated: Use InsertBatchRestrictDataPara.ProtoReflect.Descriptor instead.

func (*InsertBatchRestrictDataPara) GetCompany

func (x *InsertBatchRestrictDataPara) GetCompany() string

func (*InsertBatchRestrictDataPara) GetName

func (x *InsertBatchRestrictDataPara) GetName() string

func (*InsertBatchRestrictDataPara) GetPathUrl

func (x *InsertBatchRestrictDataPara) GetPathUrl() string

func (*InsertBatchRestrictDataPara) ProtoMessage

func (*InsertBatchRestrictDataPara) ProtoMessage()

func (*InsertBatchRestrictDataPara) ProtoReflect

func (*InsertBatchRestrictDataPara) Reset

func (x *InsertBatchRestrictDataPara) Reset()

func (*InsertBatchRestrictDataPara) String

func (x *InsertBatchRestrictDataPara) String() string

type InsertRestrictDataPara

type InsertRestrictDataPara struct {
	Id           int32  `protobuf:"varint,1,opt,name=Id,proto3" json:"Id,omitempty"`
	Data         []byte `protobuf:"bytes,2,opt,name=Data,proto3" json:"Data,omitempty"`
	Type         int32  `protobuf:"varint,3,opt,name=Type,proto3" json:"Type,omitempty"`
	Company      string `protobuf:"bytes,4,opt,name=Company,proto3" json:"Company,omitempty"`
	Name         string `protobuf:"bytes,5,opt,name=Name,proto3" json:"Name,omitempty"`
	AreaType     int32  `protobuf:"varint,7,opt,name=AreaType,proto3" json:"AreaType,omitempty"`
	FromSys      int32  `protobuf:"varint,8,opt,name=FromSys,proto3" json:"FromSys,omitempty"`
	RestrictName string `protobuf:"bytes,9,opt,name=RestrictName,proto3" json:"RestrictName,omitempty"`
	// contains filtered or unexported fields
}

func (*InsertRestrictDataPara) Descriptor deprecated

func (*InsertRestrictDataPara) Descriptor() ([]byte, []int)

Deprecated: Use InsertRestrictDataPara.ProtoReflect.Descriptor instead.

func (*InsertRestrictDataPara) GetAreaType added in v1.9.4

func (x *InsertRestrictDataPara) GetAreaType() int32

func (*InsertRestrictDataPara) GetCompany

func (x *InsertRestrictDataPara) GetCompany() string

func (*InsertRestrictDataPara) GetData

func (x *InsertRestrictDataPara) GetData() []byte

func (*InsertRestrictDataPara) GetFromSys added in v1.9.4

func (x *InsertRestrictDataPara) GetFromSys() int32

func (*InsertRestrictDataPara) GetId

func (x *InsertRestrictDataPara) GetId() int32

func (*InsertRestrictDataPara) GetName

func (x *InsertRestrictDataPara) GetName() string

func (*InsertRestrictDataPara) GetRestrictName added in v1.9.9

func (x *InsertRestrictDataPara) GetRestrictName() string

func (*InsertRestrictDataPara) GetType

func (x *InsertRestrictDataPara) GetType() int32

func (*InsertRestrictDataPara) ProtoMessage

func (*InsertRestrictDataPara) ProtoMessage()

func (*InsertRestrictDataPara) ProtoReflect

func (x *InsertRestrictDataPara) ProtoReflect() protoreflect.Message

func (*InsertRestrictDataPara) Reset

func (x *InsertRestrictDataPara) Reset()

func (*InsertRestrictDataPara) String

func (x *InsertRestrictDataPara) String() string

type RestrictAreaPara

type RestrictAreaPara struct {
	IsEdit       int32  `protobuf:"varint,1,opt,name=IsEdit,proto3" json:"IsEdit,omitempty"`
	Name         string `protobuf:"bytes,2,opt,name=Name,proto3" json:"Name,omitempty"`
	Type         int32  `protobuf:"varint,3,opt,name=Type,proto3" json:"Type,omitempty"`
	FromSys      int32  `protobuf:"varint,4,opt,name=FromSys,proto3" json:"FromSys,omitempty"`
	AreaType     int32  `protobuf:"varint,5,opt,name=AreaType,proto3" json:"AreaType,omitempty"`
	RestrictName string `protobuf:"bytes,8,opt,name=RestrictName,proto3" json:"RestrictName,omitempty"`
	Page         int32  `protobuf:"varint,6,opt,name=page,proto3" json:"page,omitempty"`
	PageSize     int32  `protobuf:"varint,7,opt,name=pageSize,proto3" json:"pageSize,omitempty"`
	// contains filtered or unexported fields
}

func (*RestrictAreaPara) Descriptor deprecated

func (*RestrictAreaPara) Descriptor() ([]byte, []int)

Deprecated: Use RestrictAreaPara.ProtoReflect.Descriptor instead.

func (*RestrictAreaPara) GetAreaType added in v1.9.6

func (x *RestrictAreaPara) GetAreaType() int32

func (*RestrictAreaPara) GetFromSys added in v1.9.4

func (x *RestrictAreaPara) GetFromSys() int32

func (*RestrictAreaPara) GetIsEdit added in v1.8.4

func (x *RestrictAreaPara) GetIsEdit() int32

func (*RestrictAreaPara) GetName added in v1.8.4

func (x *RestrictAreaPara) GetName() string

func (*RestrictAreaPara) GetPage added in v1.9.7

func (x *RestrictAreaPara) GetPage() int32

func (*RestrictAreaPara) GetPageSize added in v1.9.7

func (x *RestrictAreaPara) GetPageSize() int32

func (*RestrictAreaPara) GetRestrictName added in v1.9.9

func (x *RestrictAreaPara) GetRestrictName() string

func (*RestrictAreaPara) GetType added in v1.8.4

func (x *RestrictAreaPara) GetType() int32

func (*RestrictAreaPara) ProtoMessage

func (*RestrictAreaPara) ProtoMessage()

func (*RestrictAreaPara) ProtoReflect

func (x *RestrictAreaPara) ProtoReflect() protoreflect.Message

func (*RestrictAreaPara) Reset

func (x *RestrictAreaPara) Reset()

func (*RestrictAreaPara) String

func (x *RestrictAreaPara) String() string

type RestrictAreaResult

type RestrictAreaResult struct {
	File string `protobuf:"bytes,1,opt,name=File,proto3" json:"File,omitempty"`
	// contains filtered or unexported fields
}

func (*RestrictAreaResult) Descriptor deprecated

func (*RestrictAreaResult) Descriptor() ([]byte, []int)

Deprecated: Use RestrictAreaResult.ProtoReflect.Descriptor instead.

func (*RestrictAreaResult) GetFile

func (x *RestrictAreaResult) GetFile() string

func (*RestrictAreaResult) ProtoMessage

func (*RestrictAreaResult) ProtoMessage()

func (*RestrictAreaResult) ProtoReflect

func (x *RestrictAreaResult) ProtoReflect() protoreflect.Message

func (*RestrictAreaResult) Reset

func (x *RestrictAreaResult) Reset()

func (*RestrictAreaResult) String

func (x *RestrictAreaResult) String() string

type RestrictClient

type RestrictClient interface {
	GetRestrictArea(ctx context.Context, in *RestrictAreaPara, opts ...grpc.CallOption) (*RestrictAreaResult, error)
	InsertRestrictData(ctx context.Context, in *InsertRestrictDataPara, opts ...grpc.CallOption) (*RestrictDataResult, error)
	UpdateRestrictData(ctx context.Context, in *InsertRestrictDataPara, opts ...grpc.CallOption) (*RestrictDataResult, error)
	RestrictDataList(ctx context.Context, in *RestrictAreaPara, opts ...grpc.CallOption) (*RestrictListResult, error)
	DelRestrictData(ctx context.Context, in *DelOneRestrictDataPara, opts ...grpc.CallOption) (*RestrictListResult, error)
	InsertBatchRestrictData(ctx context.Context, in *InsertBatchRestrictDataPara, opts ...grpc.CallOption) (*RestrictDataResult, error)
}

RestrictClient is the client API for Restrict service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewRestrictClient

func NewRestrictClient(cc grpc.ClientConnInterface) RestrictClient

type RestrictDataResult

type RestrictDataResult struct {
	Id     int32  `protobuf:"varint,1,opt,name=Id,proto3" json:"Id,omitempty"`
	Data   []byte `protobuf:"bytes,2,opt,name=Data,proto3" json:"Data,omitempty"`
	IsEdit int32  `protobuf:"varint,3,opt,name=IsEdit,proto3" json:"IsEdit,omitempty"`
	Type   int32  `protobuf:"varint,4,opt,name=Type,proto3" json:"Type,omitempty"`
	// contains filtered or unexported fields
}

func (*RestrictDataResult) Descriptor deprecated

func (*RestrictDataResult) Descriptor() ([]byte, []int)

Deprecated: Use RestrictDataResult.ProtoReflect.Descriptor instead.

func (*RestrictDataResult) GetData

func (x *RestrictDataResult) GetData() []byte

func (*RestrictDataResult) GetId

func (x *RestrictDataResult) GetId() int32

func (*RestrictDataResult) GetIsEdit

func (x *RestrictDataResult) GetIsEdit() int32

func (*RestrictDataResult) GetType

func (x *RestrictDataResult) GetType() int32

func (*RestrictDataResult) ProtoMessage

func (*RestrictDataResult) ProtoMessage()

func (*RestrictDataResult) ProtoReflect

func (x *RestrictDataResult) ProtoReflect() protoreflect.Message

func (*RestrictDataResult) Reset

func (x *RestrictDataResult) Reset()

func (*RestrictDataResult) String

func (x *RestrictDataResult) String() string

type RestrictListResult

type RestrictListResult struct {
	RestrictDataList []byte `protobuf:"bytes,1,opt,name=RestrictDataList,proto3" json:"RestrictDataList,omitempty"`
	Total            int64  `protobuf:"varint,2,opt,name=Total,proto3" json:"Total,omitempty"`
	// contains filtered or unexported fields
}

func (*RestrictListResult) Descriptor deprecated

func (*RestrictListResult) Descriptor() ([]byte, []int)

Deprecated: Use RestrictListResult.ProtoReflect.Descriptor instead.

func (*RestrictListResult) GetRestrictDataList

func (x *RestrictListResult) GetRestrictDataList() []byte

func (*RestrictListResult) GetTotal added in v1.9.8

func (x *RestrictListResult) GetTotal() int64

func (*RestrictListResult) ProtoMessage

func (*RestrictListResult) ProtoMessage()

func (*RestrictListResult) ProtoReflect

func (x *RestrictListResult) ProtoReflect() protoreflect.Message

func (*RestrictListResult) Reset

func (x *RestrictListResult) Reset()

func (*RestrictListResult) String

func (x *RestrictListResult) String() string

type RestrictServer

type RestrictServer interface {
	GetRestrictArea(context.Context, *RestrictAreaPara) (*RestrictAreaResult, error)
	InsertRestrictData(context.Context, *InsertRestrictDataPara) (*RestrictDataResult, error)
	UpdateRestrictData(context.Context, *InsertRestrictDataPara) (*RestrictDataResult, error)
	RestrictDataList(context.Context, *RestrictAreaPara) (*RestrictListResult, error)
	DelRestrictData(context.Context, *DelOneRestrictDataPara) (*RestrictListResult, error)
	InsertBatchRestrictData(context.Context, *InsertBatchRestrictDataPara) (*RestrictDataResult, error)
	// contains filtered or unexported methods
}

RestrictServer is the server API for Restrict service. All implementations must embed UnimplementedRestrictServer for forward compatibility.

type UnimplementedRestrictServer

type UnimplementedRestrictServer struct{}

UnimplementedRestrictServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedRestrictServer) DelRestrictData

func (UnimplementedRestrictServer) GetRestrictArea

func (UnimplementedRestrictServer) InsertBatchRestrictData

func (UnimplementedRestrictServer) InsertRestrictData

func (UnimplementedRestrictServer) RestrictDataList

func (UnimplementedRestrictServer) UpdateRestrictData

type UnsafeRestrictServer

type UnsafeRestrictServer interface {
	// contains filtered or unexported methods
}

UnsafeRestrictServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RestrictServer will result in compilation errors.

Jump to