store_grpc

package
v1.9.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 5, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var File_store_grpc_proto protoreflect.FileDescriptor
var StoreGrpc_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "store_gprc.StoreGrpc",
	HandlerType: (*StoreGrpcServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ExecuteMissionWay",
			Handler:    _StoreGrpc_ExecuteMissionWay_Handler,
		},
		{
			MethodName: "CreateRtkAccount",
			Handler:    _StoreGrpc_CreateRtkAccount_Handler,
		},
		{
			MethodName: "GetRtkAccount",
			Handler:    _StoreGrpc_GetRtkAccount_Handler,
		},
		{
			MethodName: "ListRtkAccounts",
			Handler:    _StoreGrpc_ListRtkAccounts_Handler,
		},
		{
			MethodName: "UpdateRtkAccount",
			Handler:    _StoreGrpc_UpdateRtkAccount_Handler,
		},
		{
			MethodName: "DeleteRtkAccount",
			Handler:    _StoreGrpc_DeleteRtkAccount_Handler,
		},
		{
			MethodName: "EnableRtkAccount",
			Handler:    _StoreGrpc_EnableRtkAccount_Handler,
		},
		{
			MethodName: "DisableRtkAccount",
			Handler:    _StoreGrpc_DisableRtkAccount_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "store_grpc.proto",
}

StoreGrpc_ServiceDesc is the grpc.ServiceDesc for StoreGrpc service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterStoreGrpcServer

func RegisterStoreGrpcServer(s grpc.ServiceRegistrar, srv StoreGrpcServer)

Types

type CommonResponse added in v1.8.22

type CommonResponse struct {
	Success bool   `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*CommonResponse) Descriptor deprecated added in v1.8.22

func (*CommonResponse) Descriptor() ([]byte, []int)

Deprecated: Use CommonResponse.ProtoReflect.Descriptor instead.

func (*CommonResponse) GetMessage added in v1.8.22

func (x *CommonResponse) GetMessage() string

func (*CommonResponse) GetSuccess added in v1.8.22

func (x *CommonResponse) GetSuccess() bool

func (*CommonResponse) ProtoMessage added in v1.8.22

func (*CommonResponse) ProtoMessage()

func (*CommonResponse) ProtoReflect added in v1.8.22

func (x *CommonResponse) ProtoReflect() protoreflect.Message

func (*CommonResponse) Reset added in v1.8.22

func (x *CommonResponse) Reset()

func (*CommonResponse) String added in v1.8.22

func (x *CommonResponse) String() string

type CreateRtkAccountRequest added in v1.8.22

type CreateRtkAccountRequest struct {
	UserName   string `protobuf:"bytes,1,opt,name=user_name,json=userName,proto3" json:"user_name,omitempty"`
	Password   string `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
	Kind       string `protobuf:"bytes,3,opt,name=kind,proto3" json:"kind,omitempty"`
	Vendor     string `protobuf:"bytes,4,opt,name=vendor,proto3" json:"vendor,omitempty"`
	UsedBy     string `protobuf:"bytes,5,opt,name=used_by,json=usedBy,proto3" json:"used_by,omitempty"`
	Company    string `protobuf:"bytes,6,opt,name=company,proto3" json:"company,omitempty"`
	ExpireDate string `protobuf:"bytes,7,opt,name=expire_date,json=expireDate,proto3" json:"expire_date,omitempty"` // 有效期
	// contains filtered or unexported fields
}

func (*CreateRtkAccountRequest) Descriptor deprecated added in v1.8.22

func (*CreateRtkAccountRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateRtkAccountRequest.ProtoReflect.Descriptor instead.

func (*CreateRtkAccountRequest) GetCompany added in v1.8.22

func (x *CreateRtkAccountRequest) GetCompany() string

func (*CreateRtkAccountRequest) GetExpireDate added in v1.8.27

func (x *CreateRtkAccountRequest) GetExpireDate() string

func (*CreateRtkAccountRequest) GetKind added in v1.8.22

func (x *CreateRtkAccountRequest) GetKind() string

func (*CreateRtkAccountRequest) GetPassword added in v1.8.22

func (x *CreateRtkAccountRequest) GetPassword() string

func (*CreateRtkAccountRequest) GetUsedBy added in v1.8.22

func (x *CreateRtkAccountRequest) GetUsedBy() string

func (*CreateRtkAccountRequest) GetUserName added in v1.8.22

func (x *CreateRtkAccountRequest) GetUserName() string

func (*CreateRtkAccountRequest) GetVendor added in v1.8.22

func (x *CreateRtkAccountRequest) GetVendor() string

func (*CreateRtkAccountRequest) ProtoMessage added in v1.8.22

func (*CreateRtkAccountRequest) ProtoMessage()

func (*CreateRtkAccountRequest) ProtoReflect added in v1.8.22

func (x *CreateRtkAccountRequest) ProtoReflect() protoreflect.Message

func (*CreateRtkAccountRequest) Reset added in v1.8.22

func (x *CreateRtkAccountRequest) Reset()

func (*CreateRtkAccountRequest) String added in v1.8.22

func (x *CreateRtkAccountRequest) String() string

type DeleteRtkAccountRequest added in v1.8.22

type DeleteRtkAccountRequest struct {
	Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*DeleteRtkAccountRequest) Descriptor deprecated added in v1.8.22

func (*DeleteRtkAccountRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteRtkAccountRequest.ProtoReflect.Descriptor instead.

func (*DeleteRtkAccountRequest) GetId added in v1.8.22

func (x *DeleteRtkAccountRequest) GetId() uint32

func (*DeleteRtkAccountRequest) ProtoMessage added in v1.8.22

func (*DeleteRtkAccountRequest) ProtoMessage()

func (*DeleteRtkAccountRequest) ProtoReflect added in v1.8.22

func (x *DeleteRtkAccountRequest) ProtoReflect() protoreflect.Message

func (*DeleteRtkAccountRequest) Reset added in v1.8.22

func (x *DeleteRtkAccountRequest) Reset()

func (*DeleteRtkAccountRequest) String added in v1.8.22

func (x *DeleteRtkAccountRequest) String() string

type DisableRtkAccountRequest added in v1.8.22

type DisableRtkAccountRequest struct {
	Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*DisableRtkAccountRequest) Descriptor deprecated added in v1.8.22

func (*DisableRtkAccountRequest) Descriptor() ([]byte, []int)

Deprecated: Use DisableRtkAccountRequest.ProtoReflect.Descriptor instead.

func (*DisableRtkAccountRequest) GetId added in v1.8.22

func (x *DisableRtkAccountRequest) GetId() uint32

func (*DisableRtkAccountRequest) ProtoMessage added in v1.8.22

func (*DisableRtkAccountRequest) ProtoMessage()

func (*DisableRtkAccountRequest) ProtoReflect added in v1.8.22

func (x *DisableRtkAccountRequest) ProtoReflect() protoreflect.Message

func (*DisableRtkAccountRequest) Reset added in v1.8.22

func (x *DisableRtkAccountRequest) Reset()

func (*DisableRtkAccountRequest) String added in v1.8.22

func (x *DisableRtkAccountRequest) String() string

type EnableRtkAccountRequest added in v1.8.22

type EnableRtkAccountRequest struct {
	Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*EnableRtkAccountRequest) Descriptor deprecated added in v1.8.22

func (*EnableRtkAccountRequest) Descriptor() ([]byte, []int)

Deprecated: Use EnableRtkAccountRequest.ProtoReflect.Descriptor instead.

func (*EnableRtkAccountRequest) GetId added in v1.8.22

func (x *EnableRtkAccountRequest) GetId() uint32

func (*EnableRtkAccountRequest) ProtoMessage added in v1.8.22

func (*EnableRtkAccountRequest) ProtoMessage()

func (*EnableRtkAccountRequest) ProtoReflect added in v1.8.22

func (x *EnableRtkAccountRequest) ProtoReflect() protoreflect.Message

func (*EnableRtkAccountRequest) Reset added in v1.8.22

func (x *EnableRtkAccountRequest) Reset()

func (*EnableRtkAccountRequest) String added in v1.8.22

func (x *EnableRtkAccountRequest) String() string

type ExecuteMissionWayPara

type ExecuteMissionWayPara struct {
	MissionWayData []byte `protobuf:"bytes,1,opt,name=MissionWayData,proto3" json:"MissionWayData,omitempty"`
	Sn             string `protobuf:"bytes,2,opt,name=sn,proto3" json:"sn,omitempty"` //机库sn号
	TaskId         string `protobuf:"bytes,3,opt,name=taskId,proto3" json:"taskId,omitempty"`
	DroneSn        string `protobuf:"bytes,4,opt,name=droneSn,proto3" json:"droneSn,omitempty"` //无人机sn号
	// contains filtered or unexported fields
}

func (*ExecuteMissionWayPara) Descriptor deprecated

func (*ExecuteMissionWayPara) Descriptor() ([]byte, []int)

Deprecated: Use ExecuteMissionWayPara.ProtoReflect.Descriptor instead.

func (*ExecuteMissionWayPara) GetDroneSn added in v1.8.41

func (x *ExecuteMissionWayPara) GetDroneSn() string

func (*ExecuteMissionWayPara) GetMissionWayData

func (x *ExecuteMissionWayPara) GetMissionWayData() []byte

func (*ExecuteMissionWayPara) GetSn

func (x *ExecuteMissionWayPara) GetSn() string

func (*ExecuteMissionWayPara) GetTaskId

func (x *ExecuteMissionWayPara) GetTaskId() string

func (*ExecuteMissionWayPara) ProtoMessage

func (*ExecuteMissionWayPara) ProtoMessage()

func (*ExecuteMissionWayPara) ProtoReflect

func (x *ExecuteMissionWayPara) ProtoReflect() protoreflect.Message

func (*ExecuteMissionWayPara) Reset

func (x *ExecuteMissionWayPara) Reset()

func (*ExecuteMissionWayPara) String

func (x *ExecuteMissionWayPara) String() string

type ExecuteMissionWayResult

type ExecuteMissionWayResult struct {
	Res     bool   `protobuf:"varint,1,opt,name=res,proto3" json:"res,omitempty"`
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*ExecuteMissionWayResult) Descriptor deprecated

func (*ExecuteMissionWayResult) Descriptor() ([]byte, []int)

Deprecated: Use ExecuteMissionWayResult.ProtoReflect.Descriptor instead.

func (*ExecuteMissionWayResult) GetMessage

func (x *ExecuteMissionWayResult) GetMessage() string

func (*ExecuteMissionWayResult) GetRes

func (x *ExecuteMissionWayResult) GetRes() bool

func (*ExecuteMissionWayResult) ProtoMessage

func (*ExecuteMissionWayResult) ProtoMessage()

func (*ExecuteMissionWayResult) ProtoReflect

func (x *ExecuteMissionWayResult) ProtoReflect() protoreflect.Message

func (*ExecuteMissionWayResult) Reset

func (x *ExecuteMissionWayResult) Reset()

func (*ExecuteMissionWayResult) String

func (x *ExecuteMissionWayResult) String() string

type GetRtkAccountRequest added in v1.8.22

type GetRtkAccountRequest struct {
	Id uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*GetRtkAccountRequest) Descriptor deprecated added in v1.8.22

func (*GetRtkAccountRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetRtkAccountRequest.ProtoReflect.Descriptor instead.

func (*GetRtkAccountRequest) GetId added in v1.8.22

func (x *GetRtkAccountRequest) GetId() uint32

func (*GetRtkAccountRequest) ProtoMessage added in v1.8.22

func (*GetRtkAccountRequest) ProtoMessage()

func (*GetRtkAccountRequest) ProtoReflect added in v1.8.22

func (x *GetRtkAccountRequest) ProtoReflect() protoreflect.Message

func (*GetRtkAccountRequest) Reset added in v1.8.22

func (x *GetRtkAccountRequest) Reset()

func (*GetRtkAccountRequest) String added in v1.8.22

func (x *GetRtkAccountRequest) String() string

type ListRtkAccountsRequest added in v1.8.22

type ListRtkAccountsRequest struct {
	Company  string `protobuf:"bytes,1,opt,name=company,proto3" json:"company,omitempty"`
	Status   string `protobuf:"bytes,2,opt,name=status,proto3" json:"status,omitempty"`
	Kind     string `protobuf:"bytes,3,opt,name=kind,proto3" json:"kind,omitempty"`
	Page     int32  `protobuf:"varint,4,opt,name=page,proto3" json:"page,omitempty"`
	PageSize int32  `protobuf:"varint,5,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// contains filtered or unexported fields
}

func (*ListRtkAccountsRequest) Descriptor deprecated added in v1.8.22

func (*ListRtkAccountsRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListRtkAccountsRequest.ProtoReflect.Descriptor instead.

func (*ListRtkAccountsRequest) GetCompany added in v1.8.22

func (x *ListRtkAccountsRequest) GetCompany() string

func (*ListRtkAccountsRequest) GetKind added in v1.8.22

func (x *ListRtkAccountsRequest) GetKind() string

func (*ListRtkAccountsRequest) GetPage added in v1.8.22

func (x *ListRtkAccountsRequest) GetPage() int32

func (*ListRtkAccountsRequest) GetPageSize added in v1.8.22

func (x *ListRtkAccountsRequest) GetPageSize() int32

func (*ListRtkAccountsRequest) GetStatus added in v1.8.22

func (x *ListRtkAccountsRequest) GetStatus() string

func (*ListRtkAccountsRequest) ProtoMessage added in v1.8.22

func (*ListRtkAccountsRequest) ProtoMessage()

func (*ListRtkAccountsRequest) ProtoReflect added in v1.8.22

func (x *ListRtkAccountsRequest) ProtoReflect() protoreflect.Message

func (*ListRtkAccountsRequest) Reset added in v1.8.22

func (x *ListRtkAccountsRequest) Reset()

func (*ListRtkAccountsRequest) String added in v1.8.22

func (x *ListRtkAccountsRequest) String() string

type ListRtkAccountsResponse added in v1.8.22

type ListRtkAccountsResponse struct {
	Success  bool          `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	Message  string        `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	Accounts []*RtkAccount `protobuf:"bytes,3,rep,name=accounts,proto3" json:"accounts,omitempty"`
	Total    int32         `protobuf:"varint,4,opt,name=total,proto3" json:"total,omitempty"`
	// contains filtered or unexported fields
}

func (*ListRtkAccountsResponse) Descriptor deprecated added in v1.8.22

func (*ListRtkAccountsResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListRtkAccountsResponse.ProtoReflect.Descriptor instead.

func (*ListRtkAccountsResponse) GetAccounts added in v1.8.22

func (x *ListRtkAccountsResponse) GetAccounts() []*RtkAccount

func (*ListRtkAccountsResponse) GetMessage added in v1.8.22

func (x *ListRtkAccountsResponse) GetMessage() string

func (*ListRtkAccountsResponse) GetSuccess added in v1.8.22

func (x *ListRtkAccountsResponse) GetSuccess() bool

func (*ListRtkAccountsResponse) GetTotal added in v1.8.22

func (x *ListRtkAccountsResponse) GetTotal() int32

func (*ListRtkAccountsResponse) ProtoMessage added in v1.8.22

func (*ListRtkAccountsResponse) ProtoMessage()

func (*ListRtkAccountsResponse) ProtoReflect added in v1.8.22

func (x *ListRtkAccountsResponse) ProtoReflect() protoreflect.Message

func (*ListRtkAccountsResponse) Reset added in v1.8.22

func (x *ListRtkAccountsResponse) Reset()

func (*ListRtkAccountsResponse) String added in v1.8.22

func (x *ListRtkAccountsResponse) String() string

type RtkAccount added in v1.8.22

type RtkAccount struct {
	Id         uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	UserName   string `protobuf:"bytes,2,opt,name=user_name,json=userName,proto3" json:"user_name,omitempty"`
	Password   string `protobuf:"bytes,3,opt,name=password,proto3" json:"password,omitempty"`
	Kind       string `protobuf:"bytes,4,opt,name=kind,proto3" json:"kind,omitempty"`
	Status     string `protobuf:"bytes,5,opt,name=status,proto3" json:"status,omitempty"`
	Vendor     string `protobuf:"bytes,6,opt,name=vendor,proto3" json:"vendor,omitempty"`
	UsedBy     string `protobuf:"bytes,7,opt,name=used_by,json=usedBy,proto3" json:"used_by,omitempty"`
	Company    string `protobuf:"bytes,8,opt,name=company,proto3" json:"company,omitempty"`
	CreatedAt  string `protobuf:"bytes,9,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	UpdatedAt  string `protobuf:"bytes,10,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
	ExpireDate string `protobuf:"bytes,11,opt,name=expire_date,json=expireDate,proto3" json:"expire_date,omitempty"` // 有效期
	// contains filtered or unexported fields
}

RTK账户相关消息定义

func (*RtkAccount) Descriptor deprecated added in v1.8.22

func (*RtkAccount) Descriptor() ([]byte, []int)

Deprecated: Use RtkAccount.ProtoReflect.Descriptor instead.

func (*RtkAccount) GetCompany added in v1.8.22

func (x *RtkAccount) GetCompany() string

func (*RtkAccount) GetCreatedAt added in v1.8.22

func (x *RtkAccount) GetCreatedAt() string

func (*RtkAccount) GetExpireDate added in v1.8.27

func (x *RtkAccount) GetExpireDate() string

func (*RtkAccount) GetId added in v1.8.22

func (x *RtkAccount) GetId() uint32

func (*RtkAccount) GetKind added in v1.8.22

func (x *RtkAccount) GetKind() string

func (*RtkAccount) GetPassword added in v1.8.22

func (x *RtkAccount) GetPassword() string

func (*RtkAccount) GetStatus added in v1.8.22

func (x *RtkAccount) GetStatus() string

func (*RtkAccount) GetUpdatedAt added in v1.8.22

func (x *RtkAccount) GetUpdatedAt() string

func (*RtkAccount) GetUsedBy added in v1.8.22

func (x *RtkAccount) GetUsedBy() string

func (*RtkAccount) GetUserName added in v1.8.22

func (x *RtkAccount) GetUserName() string

func (*RtkAccount) GetVendor added in v1.8.22

func (x *RtkAccount) GetVendor() string

func (*RtkAccount) ProtoMessage added in v1.8.22

func (*RtkAccount) ProtoMessage()

func (*RtkAccount) ProtoReflect added in v1.8.22

func (x *RtkAccount) ProtoReflect() protoreflect.Message

func (*RtkAccount) Reset added in v1.8.22

func (x *RtkAccount) Reset()

func (*RtkAccount) String added in v1.8.22

func (x *RtkAccount) String() string

type RtkAccountResponse added in v1.8.22

type RtkAccountResponse struct {
	Success bool        `protobuf:"varint,1,opt,name=success,proto3" json:"success,omitempty"`
	Message string      `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	Account *RtkAccount `protobuf:"bytes,3,opt,name=account,proto3" json:"account,omitempty"`
	// contains filtered or unexported fields
}

func (*RtkAccountResponse) Descriptor deprecated added in v1.8.22

func (*RtkAccountResponse) Descriptor() ([]byte, []int)

Deprecated: Use RtkAccountResponse.ProtoReflect.Descriptor instead.

func (*RtkAccountResponse) GetAccount added in v1.8.22

func (x *RtkAccountResponse) GetAccount() *RtkAccount

func (*RtkAccountResponse) GetMessage added in v1.8.22

func (x *RtkAccountResponse) GetMessage() string

func (*RtkAccountResponse) GetSuccess added in v1.8.22

func (x *RtkAccountResponse) GetSuccess() bool

func (*RtkAccountResponse) ProtoMessage added in v1.8.22

func (*RtkAccountResponse) ProtoMessage()

func (*RtkAccountResponse) ProtoReflect added in v1.8.22

func (x *RtkAccountResponse) ProtoReflect() protoreflect.Message

func (*RtkAccountResponse) Reset added in v1.8.22

func (x *RtkAccountResponse) Reset()

func (*RtkAccountResponse) String added in v1.8.22

func (x *RtkAccountResponse) String() string

type StoreGrpcClient

type StoreGrpcClient interface {
	ExecuteMissionWay(ctx context.Context, in *ExecuteMissionWayPara, opts ...grpc.CallOption) (*ExecuteMissionWayResult, error)
	// RTK账户管理服务
	CreateRtkAccount(ctx context.Context, in *CreateRtkAccountRequest, opts ...grpc.CallOption) (*RtkAccountResponse, error)
	GetRtkAccount(ctx context.Context, in *GetRtkAccountRequest, opts ...grpc.CallOption) (*RtkAccountResponse, error)
	ListRtkAccounts(ctx context.Context, in *ListRtkAccountsRequest, opts ...grpc.CallOption) (*ListRtkAccountsResponse, error)
	UpdateRtkAccount(ctx context.Context, in *UpdateRtkAccountRequest, opts ...grpc.CallOption) (*RtkAccountResponse, error)
	DeleteRtkAccount(ctx context.Context, in *DeleteRtkAccountRequest, opts ...grpc.CallOption) (*CommonResponse, error)
	EnableRtkAccount(ctx context.Context, in *EnableRtkAccountRequest, opts ...grpc.CallOption) (*CommonResponse, error)
	DisableRtkAccount(ctx context.Context, in *DisableRtkAccountRequest, opts ...grpc.CallOption) (*CommonResponse, error)
}

StoreGrpcClient is the client API for StoreGrpc service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewStoreGrpcClient

func NewStoreGrpcClient(cc grpc.ClientConnInterface) StoreGrpcClient

type StoreGrpcServer

type StoreGrpcServer interface {
	ExecuteMissionWay(context.Context, *ExecuteMissionWayPara) (*ExecuteMissionWayResult, error)
	// RTK账户管理服务
	CreateRtkAccount(context.Context, *CreateRtkAccountRequest) (*RtkAccountResponse, error)
	GetRtkAccount(context.Context, *GetRtkAccountRequest) (*RtkAccountResponse, error)
	ListRtkAccounts(context.Context, *ListRtkAccountsRequest) (*ListRtkAccountsResponse, error)
	UpdateRtkAccount(context.Context, *UpdateRtkAccountRequest) (*RtkAccountResponse, error)
	DeleteRtkAccount(context.Context, *DeleteRtkAccountRequest) (*CommonResponse, error)
	EnableRtkAccount(context.Context, *EnableRtkAccountRequest) (*CommonResponse, error)
	DisableRtkAccount(context.Context, *DisableRtkAccountRequest) (*CommonResponse, error)
	// contains filtered or unexported methods
}

StoreGrpcServer is the server API for StoreGrpc service. All implementations must embed UnimplementedStoreGrpcServer for forward compatibility

type UnimplementedStoreGrpcServer

type UnimplementedStoreGrpcServer struct {
}

UnimplementedStoreGrpcServer must be embedded to have forward compatible implementations.

func (UnimplementedStoreGrpcServer) CreateRtkAccount added in v1.8.22

func (UnimplementedStoreGrpcServer) DeleteRtkAccount added in v1.8.22

func (UnimplementedStoreGrpcServer) DisableRtkAccount added in v1.8.22

func (UnimplementedStoreGrpcServer) EnableRtkAccount added in v1.8.22

func (UnimplementedStoreGrpcServer) ExecuteMissionWay

func (UnimplementedStoreGrpcServer) GetRtkAccount added in v1.8.22

func (UnimplementedStoreGrpcServer) ListRtkAccounts added in v1.8.22

func (UnimplementedStoreGrpcServer) UpdateRtkAccount added in v1.8.22

type UnsafeStoreGrpcServer

type UnsafeStoreGrpcServer interface {
	// contains filtered or unexported methods
}

UnsafeStoreGrpcServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to StoreGrpcServer will result in compilation errors.

type UpdateRtkAccountRequest added in v1.8.22

type UpdateRtkAccountRequest struct {
	Id         uint32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	UserName   string `protobuf:"bytes,2,opt,name=user_name,json=userName,proto3" json:"user_name,omitempty"`
	Password   string `protobuf:"bytes,3,opt,name=password,proto3" json:"password,omitempty"`
	Kind       string `protobuf:"bytes,4,opt,name=kind,proto3" json:"kind,omitempty"`
	Vendor     string `protobuf:"bytes,5,opt,name=vendor,proto3" json:"vendor,omitempty"`
	UsedBy     string `protobuf:"bytes,6,opt,name=used_by,json=usedBy,proto3" json:"used_by,omitempty"`
	Company    string `protobuf:"bytes,7,opt,name=company,proto3" json:"company,omitempty"`
	ExpireDate string `protobuf:"bytes,8,opt,name=expire_date,json=expireDate,proto3" json:"expire_date,omitempty"` // 有效期
	// contains filtered or unexported fields
}

func (*UpdateRtkAccountRequest) Descriptor deprecated added in v1.8.22

func (*UpdateRtkAccountRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateRtkAccountRequest.ProtoReflect.Descriptor instead.

func (*UpdateRtkAccountRequest) GetCompany added in v1.8.22

func (x *UpdateRtkAccountRequest) GetCompany() string

func (*UpdateRtkAccountRequest) GetExpireDate added in v1.8.27

func (x *UpdateRtkAccountRequest) GetExpireDate() string

func (*UpdateRtkAccountRequest) GetId added in v1.8.22

func (x *UpdateRtkAccountRequest) GetId() uint32

func (*UpdateRtkAccountRequest) GetKind added in v1.8.22

func (x *UpdateRtkAccountRequest) GetKind() string

func (*UpdateRtkAccountRequest) GetPassword added in v1.8.22

func (x *UpdateRtkAccountRequest) GetPassword() string

func (*UpdateRtkAccountRequest) GetUsedBy added in v1.8.22

func (x *UpdateRtkAccountRequest) GetUsedBy() string

func (*UpdateRtkAccountRequest) GetUserName added in v1.8.22

func (x *UpdateRtkAccountRequest) GetUserName() string

func (*UpdateRtkAccountRequest) GetVendor added in v1.8.22

func (x *UpdateRtkAccountRequest) GetVendor() string

func (*UpdateRtkAccountRequest) ProtoMessage added in v1.8.22

func (*UpdateRtkAccountRequest) ProtoMessage()

func (*UpdateRtkAccountRequest) ProtoReflect added in v1.8.22

func (x *UpdateRtkAccountRequest) ProtoReflect() protoreflect.Message

func (*UpdateRtkAccountRequest) Reset added in v1.8.22

func (x *UpdateRtkAccountRequest) Reset()

func (*UpdateRtkAccountRequest) String added in v1.8.22

func (x *UpdateRtkAccountRequest) String() string

Jump to